#[repr(C)]pub struct FIFinderSyncController { /* private fields */ }Implementations
sourceimpl FIFinderSyncController
impl FIFinderSyncController
pub unsafe fn defaultController() -> Retained<Self>
pub unsafe fn directoryURLs(&self) -> Retained<NSSet<NSURL>>
pub unsafe fn setDirectoryURLs(&self, directory_ur_ls: Option<&NSSet<NSURL>>)
pub unsafe fn setBadgeImage_label_forBadgeIdentifier( &self, image: &NSImage, label: Option<&NSString>, badge_id: &NSString )
Available on crate feature
objc2-app-kit only.pub unsafe fn setBadgeIdentifier_forURL(&self, badge_id: &NSString, url: &NSURL)
pub unsafe fn targetedURL(&self) -> Option<Retained<NSURL>>
pub unsafe fn selectedItemURLs(&self) -> Option<Retained<NSArray<NSURL>>>
pub unsafe fn lastUsedDateForItemWithURL( &self, item_url: &NSURL ) -> Option<Retained<NSDate>>
pub unsafe fn setLastUsedDate_forItemWithURL_completion( &self, last_used_date: &NSDate, item_url: &NSURL, completion: &Block<dyn Fn(NonNull<NSError>)> )
Available on crate feature
block2 only.pub unsafe fn tagDataForItemWithURL( &self, item_url: &NSURL ) -> Option<Retained<NSData>>
pub unsafe fn setTagData_forItemWithURL_completion( &self, tag_data: Option<&NSData>, item_url: &NSURL, completion: &Block<dyn Fn(NonNull<NSError>)> )
Available on crate feature
block2 only.pub unsafe fn isExtensionEnabled() -> bool
pub unsafe fn showExtensionManagementInterface()
Methods from Deref<Target = NSExtensionContext>
pub unsafe fn inputItems(&self) -> Retained<NSArray>
Available on crate feature
NSArray only.pub unsafe fn completeRequestReturningItems_completionHandler( &self, items: Option<&NSArray>, completion_handler: Option<&Block<dyn Fn(Bool)>> )
Available on crate features
NSArray and block2 only.pub unsafe fn cancelRequestWithError(&self, error: &NSError)
Available on crate feature
NSError only.pub unsafe fn openURL_completionHandler( &self, url: &NSURL, completion_handler: Option<&Block<dyn Fn(Bool)>> )
Available on crate features
NSURL and block2 only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.