#[repr(transparent)]pub struct FIMenuKind(pub NSUInteger);Expand description
The different kinds of custom menus that the Finder Sync extension can provide.
See also Apple’s documentation
Tuple Fields
0: NSUIntegerImplementations
Sourceimpl FIMenuKind
impl FIMenuKind
Sourcepub const ContextualMenuForItems: Self
pub const ContextualMenuForItems: Self
A shortcut menu created when the user control-clicks on an item or a group of selected items inside the Finder window.
Sourcepub const ContextualMenuForContainer: Self
pub const ContextualMenuForContainer: Self
A shortcut menu created when the user control-clicks on the Finder window’s background.
Sourcepub const ContextualMenuForSidebar: Self
pub const ContextualMenuForSidebar: Self
A shortcut menu created when the user control-clicks on an item in the sidebar.
Sourcepub const ToolbarItemMenu: Self
pub const ToolbarItemMenu: Self
A menu created when the user clicks on the extension’s toolbar button.